<!--
SPDX-FileCopyrightText: Contributors to the Power Grid Model project <powergridmodel@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->

# Package tests

This folder contains a separate CMake project to test the installation of the package containing the C API.

See the
[package tests documentation](https://power-grid-model.readthedocs.io/en/stable/advanced_documentation/build-guide.html#package-tests)
for more information.
